@@ -1,9 +1,11 @@
+# $Id: Loop.pm 2357 2008-06-20 17:41:54Z rcaputo $
+
 package POE::Loop;
 
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '1.294_512'; # NOTE - Should be #.### (three decimal places)
+$VERSION = do {my($r)=(q$Revision: 2357 $=~/(\d+)/);sprintf"1.%04d",$r};
 
 1;
 
@@ -46,7 +48,7 @@ As POE::Kernel loads, it searches through %INC for event loop modules.
 POE::Kernel loads the most appropriate POE::Loop subclass for the
 event loop it finds.  The subclass slots its methods into POE::Kernel,
 completing the class at load time.  POE and POE::Kernel provide ways
-to state the desired event loop in case the auto-detection makes a
+to state the desired event loop in case the autodetection makes a
 mistake or the developer prefers to be explicit.  See
 L<POE::Kernel/"Using POE with Other Event Loops"> for instructions on
 how to actually use POE with other event loops, event loop naming
@@ -80,7 +82,7 @@ Here is a skeleton of a POE::Loop subclass:
   package POE::Loop::YourToolkit;
 
   use vars qw($VERSION);
-  $VERSION = '1.000'; # NOTE - Should be #.### (three decimal places)
+  $VERSION = do {my@r=(q$Revision: 2357 $=~/\d+/g);sprintf"%d."."%04d"x$#r,@r};
 
   package POE::Kernel;
 
@@ -256,7 +258,7 @@ Watch for a given SIGNAL_NAME.  SIGNAL_NAME is the version found in
 "SIG" removed.
 
 POE::Loop::PerlSignals' implementation adds callbacks to %SIG except
-for CHLD/CLD, which begins a waitpid() polling loop instead.
+for CHLD/CLD, which begins a waitpid() pollng loop instead.
 
 As of this writing, all of the POE::Loop subclasses register their
 signal handlers through POE::Loop::PerlSignals.
@@ -315,7 +317,7 @@ Here's Gtk's:
           $self->_dispatch_event(
             $self, $self,
             EN_SIGNAL, ET_SIGNAL, [ 'UIDESTROY' ],
-            __FILE__, __LINE__, undef, time(), -__LINE__
+            __FILE__, __LINE__, time(), -__LINE__
           );
         }
         return 0;
@@ -337,8 +339,8 @@ dispatched.
 
 The time management methods may accept NEXT_EVENT_TIME.  This is the
 time the next event will become due, in UNIX epoch time.
-NEXT_EVENT_TIME is a real number and may have sub-second accuracy.  It
-is the bridge's responsibility to convert this value into something
+NEXT_EVENT_TIME is a real number and may have subsecond accuracy.  It
+is the bridge's responsibility to convert this value intos something
 the underlying event loop requires.
 
 =head3 loop_resume_time_watcher NEXT_EVENT_TIME
@@ -346,7 +348,7 @@ the underlying event loop requires.
 Resume an already active time watcher.  It is used with
 loop_pause_time_watcher() to provide less expensive timer toggling for
 frequent use cases.  As mentioned above, NEXT_EVENT_TIME is in UNIX
-epoch time and may have sub-second accuracy.
+epoch time and may have subsecond accuracy.
 
 loop_resume_time_watcher() is used by bridges that set them watchers
 in the underlying event loop.  For example, POE::Loop::Gtk implements
@@ -569,4 +571,3 @@ and POE's licensing.
 =cut
 
 # rocco // vim: ts=2 sw=2 expandtab
-# TODO - Edit.
